"Namespace definitions"


# XML namespaces
XML_SCHEMA = "http://www.w3.org/2001/XMLSchema"
XML_SCHEMA_INSTANCE = "http://www.w3.org/2001/XMLSchema-instance"

# SOAP namespaces
SOAP_ENV = "http://www.w3.org/2003/05/soap-envelope"

# Web services security namespaces
WSS_PWDIGEST = "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-username-token-profile-1.0#PasswordDigest"
WSS_BASE64BIN = "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-soap-message-security-1.0#Base64Binary"
WSS_SECUTIL = "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-utility-1.0.xsd"
WSS_SECEXT = "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd"

# Onvif base namespaces for schema, device, media & ptz
OVF_SCHEMA = "http://www.onvif.org/ver10/schema"
OVF_DEVICE = "http://www.onvif.org/ver10/device/wsdl"
OVF_MEDIA = "http://www.onvif.org/ver10/media/wsdl"
OVF_PTZ = "http://www.onvif.org/ver20/ptz/wsdl"

# Onvif zoom spaces
OVF_ZS_VGS = "http://www.onvif.org/ver10/tptz/ZoomSpaces/VelocityGenericSpace"
OVF_ZS_TGS = "http://www.onvif.org/ver10/tptz/ZoomSpaces/TranslationGenericSpace"
OVF_ZS_PGS = "http://www.onvif.org/ver10/tptz/ZoomSpaces/PositionGenericSpace"
OVF_ZS_ZGSS = "http://www.onvif.org/ver10/tptz/ZoomSpaces/ZoomGenericSpeedSpace"

# Onvif pan & tilt spaces
OVF_PTS_VGS = "http://www.onvif.org/ver10/tptz/PanTiltSpaces/VelocityGenericSpace"
OVF_PTS_TGS = "http://www.onvif.org/ver10/tptz/PanTiltSpaces/TranslationGenericSpace"
OVF_PTS_PGS = "http://www.onvif.org/ver10/tptz/PanTiltSpaces/PositionGenericSpace"
OVF_PTS_GSS = "http://www.onvif.org/ver10/tptz/PanTiltSpaces/GenericSpeedSpace"
